@@ -3,7 +3,6 @@ from __future__ import print_function, absolute_import
 import os
 import os.path
 import uuid
-import tempfile
 import numpy as np
 
 try:
@@ -21,21 +20,16 @@ from .utils.py_utils import FileManager, tempfolder
 from . import config
 
 __all__ = [
-    'FileStructure',
-    'TextStructure',
-    'RdkitStructure',
-    'PdbIdStructure',
-    'ASEStructure',
+    'FileStructure', 'TextStructure', 'RdkitStructure', 'PdbIdStructure',
+    'ASEStructure', 'BiopythonStructure', 'IOTBXStructure',
+    'RosettaStructure',
     'SimpletrajTrajectory',
-    'MDTrajTrajectory',
-    'PyTrajTrajectory',
-    'ParmEdTrajectory',
-    'MDAnalysisTrajectory',
-    'HTMDTrajectory',
-    'ASETrajectory',
-    'register_backend'
+    'MDTrajTrajectory', 'PyTrajTrajectory', 'ParmEdTrajectory',
+    'MDAnalysisTrajectory', 'HTMDTrajectory', 'ASETrajectory',
+    'register_backend',
 ]
 
+
 class register_backend(object):
     def __init__(self, package_name):
         # package_name must match exactly to your Python package
@@ -45,8 +39,8 @@ class register_backend(object):
         config.BACKENDS[self.package_name] = cls
         return cls
 
-class FileStructure(Structure):
 
+class FileStructure(Structure):
     def __init__(self, path):
         super(FileStructure, self).__init__()
         self.fm = FileManager(path)
@@ -59,7 +53,6 @@ class FileStructure(Structure):
 
 
 class TextStructure(Structure):
-
     def __init__(self, text, ext='pdb', params={}):
         super(TextStructure, self).__init__()
         self.path = ''
@@ -72,7 +65,6 @@ class TextStructure(Structure):
 
 
 class RdkitStructure(Structure):
-
     def __init__(self, rdkit_mol, ext="pdb"):
         super(RdkitStructure, self).__init__()
         self.path = ''
@@ -86,8 +78,26 @@ class RdkitStructure(Structure):
         return fh.read()
 
 
-class PdbIdStructure(Structure):
+class SchrodingerStructure(Structure):
+    '''Only read first structure
+    '''
+    def __init__(self, structure, ext="pdb"):
+        super(SchrodingerStructure, self).__init__()
+        self.path = ''
+        self.ext = ext
+        self.params = {}
+        self._schrodinger_structure = structure
 
+    def get_structure_string(self):
+        with tempfolder():
+            pdb_fn = 'tmp.pdb'
+            self._schrodinger_structure.write(pdb_fn)
+            with open(pdb_fn) as fh:
+                content = fh.read()
+        return content
+
+
+class PdbIdStructure(Structure):
     def __init__(self, pdbid):
         super(PdbIdStructure, self).__init__()
         self.pdbid = pdbid
@@ -100,7 +110,6 @@ class PdbIdStructure(Structure):
 
 
 class ASEStructure(Structure):
-
     def __init__(self, ase_atoms, ext='pdb', params={}):
         super(ASEStructure, self).__init__()
         self.path = ''
@@ -114,6 +123,57 @@ class ASEStructure(Structure):
             return open('tmp.pdb').read()
 
 
+class BiopythonStructure(Structure):
+    def __init__(self, entity, ext='pdb', params={}):
+        super(BiopythonStructure, self).__init__()
+        self.path = ''
+        self.ext = ext
+        self.params = params
+        self._entity = entity
+
+    def get_structure_string(self):
+        from Bio.PDB import PDBIO
+        try:
+            from StringIO import StringIO
+        except ImportError:
+            from io import StringIO
+        io_pdb = PDBIO()
+        io_pdb.set_structure(self._entity)
+        io_str = StringIO()
+        io_pdb.save(io_str)
+        return io_str.getvalue()
+
+
+class IOTBXStructure(Structure):
+    def __init__(self, obj, ext='pdb', params={}):
+        """
+        obj must have as_pdb_string method
+        """
+        super(IOTBXStructure, self).__init__()
+        self.path = ''
+        self.ext = ext
+        self.params = params
+        self._mol = obj
+
+    def get_structure_string(self):
+        return self._mol.as_pdb_string()
+
+
+class RosettaStructure(Structure):
+    def __init__(self, pose, ext='pdb', params={}):
+        # type: (pyrosetta.rosetta.core.pose.Pose, str, Dict) -> None
+        super(RosettaStructure, self).__init__()
+        self.path = ''
+        self.ext = ext
+        self.params = params
+        self._mol = pose
+
+    def get_structure_string(self):
+        with tempfolder():
+            self._mol.dump_pdb('tmp.pdb')
+            return open('tmp.pdb').read()
+
+
 @register_backend('simpletraj')
 class SimpletrajTrajectory(Trajectory, Structure):
     '''simpletraj adaptor.
@@ -131,8 +191,7 @@ class SimpletrajTrajectory(Trajectory, Structure):
             import simpletraj
         except ImportError as e:
             raise ImportError(
-                "'SimpletrajTrajectory' requires the 'simpletraj' package"
-            )
+                "'SimpletrajTrajectory' requires the 'simpletraj' package")
         self.traj_cache = simpletraj.trajectory.TrajectoryCache()
         self.path = path
         self._structure_path = structure_path
@@ -187,10 +246,11 @@ class MDTrajTrajectory(Trajectory, Structure):
         return self.trajectory.n_frames
 
     def get_structure_string(self):
-        fd, fname = tempfile.mkstemp()
-        self.trajectory[0].save_pdb(fname)
-        pdb_string = os.fdopen(fd).read()
-        # os.close( fd )
+        with tempfolder():
+            fname = 'tmp.pdb'
+            self.trajectory[0].save_pdb(fname)
+            with open(fname) as fh:
+                pdb_string = fh.read()
         return pdb_string
 
 
@@ -222,10 +282,11 @@ class PyTrajTrajectory(Trajectory, Structure):
         return self.trajectory.n_frames
 
     def get_structure_string(self):
-        fd, fname = tempfile.mkstemp(suffix=".pdb")
-        self.trajectory[:1].save(fname, format="pdb", overwrite=True)
-        pdb_string = os.fdopen(fd).read()
-        # os.close( fd )
+        fname = 'tmp.pdb'
+        with tempfolder():
+            self.trajectory[:1].save(fname, format="pdb", overwrite=True)
+            with open(fname) as fh:
+                pdb_string = fh.read()
         return pdb_string
 
 
@@ -251,16 +312,18 @@ class ParmEdTrajectory(Trajectory, Structure):
         return len(self._xyz)
 
     def get_structure_string(self):
-        fd, fname = tempfile.mkstemp(suffix=".pdb")
         # only write 1st model
-        if self.only_save_1st_model:
-            self.trajectory.save(
-                fname, overwrite=True,
-                coordinates=self.trajectory.coordinates)
-        else:
-            self.trajectory.save(fname, overwrite=True)
-        pdb_string = os.fdopen(fd).read()
-        # os.close( fd )
+        fname = 'tmp.pdb'
+        with tempfolder():
+            if self.only_save_1st_model:
+                self.trajectory.save(
+                    fname,
+                    overwrite=True,
+                    coordinates=self.trajectory.coordinates)
+            else:
+                self.trajectory.save(fname, overwrite=True)
+            with open(fname) as fh:
+                pdb_string = fh.read()
         return pdb_string
 
 
@@ -301,8 +364,7 @@ class MDAnalysisTrajectory(Trajectory, Structure):
             import MDAnalysis as mda
         except ImportError:
             raise ImportError(
-                "'MDAnalysisTrajectory' requires the 'MDAnalysis' package"
-            )
+                "'MDAnalysisTrajectory' requires the 'MDAnalysis' package")
         u = self.atomgroup.universe
         u.trajectory[0]
         f = mda.lib.util.NamedStream(StringIO(), 'tmp.pdb')
@@ -330,6 +392,7 @@ class HTMDTrajectory(Trajectory):
     >>> w = nv.NGLWidget(t)
     >>> w
     '''
+
     def __init__(self, mol):
         self.mol = mol
         self.ext = "pdb"
@@ -344,11 +407,11 @@ class HTMDTrajectory(Trajectory):
         return self.mol.numFrames
 
     def get_structure_string(self):
-        import tempfile
-        fd, fname = tempfile.mkstemp(suffix='.pdb')
-        self.mol.write(fname)
-        pdb_string = os.fdopen(fd).read()
-        # os.close( fd )
+        fname = 'tmp.pdb'
+        with tempfolder():
+            self.mol.write(fname)
+            with open(fname) as fh:
+                pdb_string = fh.read()
         return pdb_string
 
 
