@@ -7,18 +7,12 @@ except ImportError:
 
 from .widget import NGLWidget
 from . import datafiles
-
-from .adaptor import (
-    FileStructure,
-    TextStructure,
-    PdbIdStructure,
-    ASEStructure,
-    MDTrajTrajectory,
-    PyTrajTrajectory,
-    ParmEdTrajectory,
-    MDAnalysisTrajectory,
-    HTMDTrajectory,
-    ASETrajectory)
+from .adaptor import (FileStructure, TextStructure, PdbIdStructure,
+                      ASEStructure, BiopythonStructure, IOTBXStructure,
+                      RosettaStructure,
+                      MDTrajTrajectory,
+                      PyTrajTrajectory, ParmEdTrajectory, MDAnalysisTrajectory,
+                      HTMDTrajectory, ASETrajectory, SchrodingerStructure)
 
 __all__ = [
     'demo',
@@ -26,6 +20,8 @@ __all__ = [
     'show_url',
     'show_text',
     'show_ase',
+    'show_iotbx',
+    'show_rosetta',
     'show_asetraj',
     'show_simpletraj',
     'show_mdtraj',
@@ -34,7 +30,12 @@ __all__ = [
     'show_parmed',
     'show_rdkit',
     'show_structure_file',
-    'show_htmd',]
+    'show_file',
+    'show_htmd',
+    'show_schrodinger',
+    'show_biopython',
+]
+
 
 def show_pdbid(pdbid, **kwargs):
     '''Show PDB entry.
@@ -48,18 +49,21 @@ def show_pdbid(pdbid, **kwargs):
     structure = PdbIdStructure(pdbid)
     return NGLWidget(structure, **kwargs)
 
+
 def show_url(url, **kwargs):
     kwargs2 = dict((k, v) for k, v in kwargs.items())
     view = NGLWidget()
     view.add_component(url, **kwargs2)
     return view
 
+
 def show_text(text, **kwargs):
     """for development
     """
     structure = TextStructure(text)
     return NGLWidget(structure, **kwargs)
 
+
 def show_ase(ase_atoms, **kwargs):
     """
 
@@ -76,6 +80,37 @@ def show_ase(ase_atoms, **kwargs):
     structure = ASEStructure(ase_atoms)
     return NGLWidget(structure, **kwargs)
 
+
+def show_iotbx(mol, **kwargs):
+    """
+
+    Examples
+    --------
+    >>> import iotbx.pdb
+    ... x = iotbx.pdb.hierarchy.input('file.pdb')
+    ... mol = x.construct_hierarchy()
+    ... view = nglview.show_iotbx(hi)
+    ... view # doctest: +SKIP
+    """
+    structure = IOTBXStructure(mol)
+    return NGLWidget(structure, **kwargs)
+
+
+def show_rosetta(pose, **kwargs):
+    """
+
+    Examples
+    --------
+    >>> from pyrosetta import pose_from_sequence, init
+    ... init()
+    ... pose = pose_from_sequence('AAAAAA')
+    ... view = nglview.show_rosetta(pose)
+    ... view # doctest: +SKIP
+    """
+    structure = RosettaStructure(pose)
+    return NGLWidget(structure, **kwargs)
+
+
 def show_asetraj(ase_traj, **kwargs):
     '''Show ase trajectory and structure file.
 
@@ -91,6 +126,7 @@ def show_asetraj(ase_traj, **kwargs):
     trajectory = ASETrajectory(ase_traj)
     return NGLWidget(trajectory, **kwargs)
 
+
 def show_structure_file(path, **kwargs):
     '''Show structure file. Allowed are text-based structure
     file formats that are by supported by NGL, including pdb,
@@ -106,6 +142,20 @@ def show_structure_file(path, **kwargs):
     return NGLWidget(structure, **kwargs)
 
 
+def show_file(path, **kwargs):
+    '''Show any supported file format (e.g: .gro, .dx, ...)
+
+    Examples
+    --------
+    >>> import nglview as nv
+    ... w = nv.show_file('my.dx')
+    ... w # doctest: +SKIP
+    '''
+    view = NGLWidget()
+    view.add_component(path, **kwargs)
+    return view
+
+
 def show_simpletraj(traj, **kwargs):
     '''Show simpletraj trajectory and structure file.
 
@@ -145,7 +195,10 @@ def show_pytraj(pytraj_trajectory, **kwargs):
     >>> w = nv.show_pytraj(t)
     >>> w # doctest: +SKIP
     '''
-    trajlist = pytraj_trajectory if isinstance(pytraj_trajectory, (list, tuple)) else [pytraj_trajectory,]
+    trajlist = pytraj_trajectory if isinstance(pytraj_trajectory,
+                                               (list, tuple)) else [
+                                                   pytraj_trajectory,
+                                               ]
 
     trajlist = [PyTrajTrajectory(traj) for traj in trajlist]
     return NGLWidget(trajlist, **kwargs)
@@ -165,6 +218,7 @@ def show_parmed(parmed_structure, **kwargs):
     structure_trajectory = ParmEdTrajectory(parmed_structure)
     return NGLWidget(structure_trajectory, **kwargs)
 
+
 def show_rdkit(rdkit_mol, **kwargs):
     '''Show rdkit's Mol.
 
@@ -176,22 +230,22 @@ def show_rdkit(rdkit_mol, **kwargs):
     Examples
     --------
     >>> import nglview as nv
-    >>> from rdkit import Chem
-    >>> from rdkit.Chem import AllChem
-    >>> m = Chem.AddHs(Chem.MolFromSmiles('COc1ccc2[C@H](O)[C@@H](COc2c1)N3CCC(O)(CC3)c4ccc(F)cc4'))
-    >>> _ = AllChem.EmbedMultipleConfs(m, useExpTorsionAnglePrefs=True, useBasicKnowledge=True)
-    >>> view = nv.show_rdkit(m)
-    >>> view # doctest: +SKIP
+    >>> from rdkit import Chem # doctest: +SKIP
+    ... from rdkit.Chem import AllChem
+    ... m = Chem.AddHs(Chem.MolFromSmiles('COc1ccc2[C@H](O)[C@@H](COc2c1)N3CCC(O)(CC3)c4ccc(F)cc4'))
+    ... _ = AllChem.EmbedMultipleConfs(m, useExpTorsionAnglePrefs=True, useBasicKnowledge=True)
+    ... view = nv.show_rdkit(m)
+    ... view # doctest: +SKIP
 
     >>> # add component m2
     >>> # create file-like object
     >>> from nglview.show import StringIO
-    >>> m2 = Chem.AddHs(Chem.MolFromSmiles('N[C@H](C)C(=O)O'))
-    >>> fh = StringIO(Chem.MolToPDBBlock(m2))
-    >>> view.add_component(fh, ext='pdb')
+    >>> m2 = Chem.AddHs(Chem.MolFromSmiles('N[C@H](C)C(=O)O')) # doctest: +SKIP
+    ... fh = StringIO(Chem.MolToPDBBlock(m2))
+    ... view.add_component(fh, ext='pdb')
 
     >>> # load as trajectory, need to have ParmEd
-    >>> view = nv.show_rdkit(m, parmed=True)
+    >>> view = nv.show_rdkit(m, parmed=True) # doctest: +SKIP
     '''
     from rdkit import Chem
     fh = StringIO(Chem.MolToPDBBlock(rdkit_mol))
@@ -219,6 +273,7 @@ def show_rdkit(rdkit_mol, **kwargs):
         # parm_nv.params = dict(firstModelOnly=True)
         return NGLWidget(parm_nv, **kwargs)
 
+
 def show_mdanalysis(atomgroup, **kwargs):
     '''Show NGL widget with MDAnalysis AtomGroup.
 
@@ -226,16 +281,17 @@ def show_mdanalysis(atomgroup, **kwargs):
 
     Examples
     --------
-    >>> import nglview as nv
-    >>> import MDAnalysis as mda
-    >>> u = mda.Universe(nv.datafiles.GRO, nv.datafiles.XTC)
-    >>> prot = u.select_atoms('protein')
-    >>> w = nv.show_mdanalysis(prot)
-    >>> w # doctest: +SKIP
+        import nglview as nv
+        import MDAnalysis as mda
+        u = mda.Universe(nv.datafiles.GRO, nv.datafiles.XTC)
+        prot = u.select_atoms('protein')
+        w = nv.show_mdanalysis(prot)
+        w # doctest: +SKIP
     '''
     structure_trajectory = MDAnalysisTrajectory(atomgroup)
     return NGLWidget(structure_trajectory, **kwargs)
 
+
 def show_htmd(mol, **kwargs):
     '''Show NGL widget with HTMD Molecule.
 
@@ -253,6 +309,46 @@ def show_htmd(mol, **kwargs):
     structure_trajectory = HTMDTrajectory(mol)
     return NGLWidget(structure_trajectory, **kwargs)
 
+
+def show_schrodinger(mol, **kwargs):
+    '''Show NGL widget with Schrodinger's Structure
+
+    Notes
+    -----
+    EXPERIMENTAL
+
+    Examples
+    --------
+    >>> import nglview as nv # doctest: +SKIP
+    ... from schrodinger.structure import StructureReader
+    ... for s in StructureReader(fn):
+    ...    break
+    ... w = nv.show_schrodinger(s)
+    ... w
+    '''
+    structure_trajectory = SchrodingerStructure(mol)
+    return NGLWidget(structure_trajectory, **kwargs)
+
+
+def show_biopython(entity, **kwargs):
+    '''Show NGL widget with Biopython structural entity.
+
+    Takes a Structure, Model, Chain, Residue or Atom
+    from Bio.PDB as its data input.
+
+    Examples
+    --------
+    >>> import nglview as nv # doctest: +SKIP
+    ... from Bio.PDB import PDBParser
+    ... parser = PDBParser()
+    ... structure = parser.get_structure("protein", "protein.pdb")
+    ... w = nv.show_biopython(structure[0]["A"])
+    ... w
+    '''
+    entity = BiopythonStructure(entity)
+    return NGLWidget(entity, **kwargs)
+
+
 def demo(*args, **kwargs):
     '''
 
