@@ -5,24 +5,32 @@ import pytest
 import nglview
 from nglview.utils import py_utils, js_utils
 from nglview.utils.py_utils import seq_to_string, _camelize, _camelize_dict, FileManager
+
+# local
+from utils import repr_dict as repr_dict_example
 import gzip
 
 # local
 from utils import get_fn
 
+
 def assert_equal(x, y):
     assert x == y
 
+
 def test_get_name():
     fn = nglview.datafiles.PDB
     assert_equal(py_utils.get_name(object, dict(name='hello')), 'hello')
-    assert_equal(py_utils.get_name(nglview.FileStructure(fn), dict()),
-            'nglview.adaptor.FileStructure')
+    assert_equal(
+        py_utils.get_name(nglview.FileStructure(fn), dict()),
+        'nglview.adaptor.FileStructure')
+
 
 def test_seq_to_string():
     assert_equal(seq_to_string([1, 2, 3]), '@1,2,3')
     assert_equal(seq_to_string('@1,2,3'), '@1,2,3')
 
+
 def test_camelize():
     assert_equal(_camelize('remote_call'), 'remoteCall')
     assert_equal(_camelize('flat_shaded'), 'flatShaded')
@@ -45,11 +53,13 @@ def test_camelize():
     assert_equal(_camelize('maxDistance'), 'maxDistance')
     assert_equal(_camelize('color'), 'color')
 
+
 def test_dict():
     kwargs = dict(default_representation=True)
     kwargs2 = _camelize_dict(kwargs)
     assert 'defaultRepresentation' in kwargs2
 
+
 def test_file_manager_use_url():
     fh = FileManager('rcsb://1tsu.pdb')
     assert fh.is_url
@@ -65,6 +75,7 @@ def test_file_manager_use_url():
     assert_equal(fh.ext, 'pdb')
     assert fh.is_compressed
 
+
 def test_file_not_use_filename():
     src = os.path.join(os.path.dirname(nglview.__file__), '__init__.py')
     fh = FileManager(src)
@@ -89,7 +100,7 @@ def test_file_current_folder():
 
     assert fh.ext.endswith('pdb')
     assert fh.is_filename
-    assert fh.read() == fh.src
+    assert fh.read() == os.path.relpath(fh.src)
 
     with open(src) as src2:
         fh2 = FileManager(src2)
@@ -104,13 +115,14 @@ def test_file_current_folder():
         assert fh_content != src2.read()
 
     fh3 = FileManager(src)
-    content = open(src, 'rb').read() 
+    content = open(src, 'rb').read()
     assert_equal(fh3.read(force_buffer=True), content)
 
     # blob
     fh4 = FileManager(content)
     assert_equal(fh4.read(force_buffer=True), content)
 
+
 def test_file_gz():
     src = get_fn('tz2_2.pdb.gz')
     fh = FileManager(src)
@@ -140,9 +152,10 @@ def test_file_gz():
     fh4 = FileManager(src, compressed=True)
     assert fh4.is_compressed
 
-    content = gzip.open(src).read() 
+    content = gzip.open(src).read()
     assert_equal(fh4.read(force_buffer=True), content)
 
+
 def test_file_passing_blob():
     src = get_fn('tz2.pdb')
     blob = open(src).read()
@@ -152,6 +165,7 @@ def test_file_passing_blob():
     with pytest.raises(ValueError):
         fm.ext
 
+
 def test_file_passing_blob_from_gzip():
     import gzip
     src = get_fn('tz2_2.pdb.gz')
@@ -163,15 +177,12 @@ def test_file_passing_blob_from_gzip():
     with pytest.raises(ValueError):
         fm.ext
 
-def test_get_repr_names_from_dict():
-    fake_repr_dict = dict(c0={'0': {'name': 'cartoon'},
-                              '1': {'name': 'licorice'}},
-                          c1={'0': {'name': 'base'}})
 
-    assert_equal(py_utils.get_repr_names_from_dict(fake_repr_dict, 0),
-                    ['cartoon', 'licorice'])
-    assert_equal(py_utils.get_repr_names_from_dict(fake_repr_dict, 1),
-                    ['base'])
+def test_get_repr_names_from_dict():
+    assert_equal(
+        py_utils.get_repr_names_from_dict(repr_dict_example, 0),
+        ['cartoon', 'base', 'ball+stick'])
+
 
 def test_js_utils():
     js_utils.launch_qtconsole()
